import React from 'react';
import { Grid, Tooltip } from "@material-ui/core";
import { CustomTable } from '../common/table/CustomTable';
import { HostStatusIcon } from './HostIcons';
import { noWrapText } from '../common/Helper';
import { useRedirect } from '../../hooks/Redirect';

const columns = [
    { id: 'bulb', label: 'Status', width: '8ch', textAlign: "center" },
    { id: 'host', label: 'Host', width: '15ch' },
    { id: 'description', label: 'Description', width: '15ch' },
    { id: 'network', label: 'Network', width: '10ch' },
    { id: 'scope', label: 'Scope', width: '10ch' },
    { id: 'deviceType', label: 'Device Type', width: '13ch' },
];

export function rowDescription(description) {

    return (
        <div className={'shortenLongDataLines'}>
            <Tooltip title={description} arrow enterDelay={400}>
                <label>{noWrapText(description)}</label>
            </Tooltip>
        </div>
    );
}

export function createRow(hostContainer) {
    const host = hostContainer.csEntryHost;
    return {
        id: host.id,
        bulb:
            <Grid container direction="column" justifyContent="center" alignItems="center">
                <HostStatusIcon host={hostContainer} />
            </Grid>,
        host: noWrapText(host.name),
        description: rowDescription(host.description),
        network: noWrapText(host.network),
        deviceType: noWrapText(host.deviceType),
        scope: noWrapText(host.scope),
        discrepancy: hostContainer.alert === "WARNING",
        inconsistentState: hostContainer.alert === "ERROR",
        shortenLongData: true,
    };

}

export function HostTable({ hosts, totalCount, lazyParams, setLazyParams, columnSort, setColumnSort, rowsPerPage, loading}) {
    const redirect = useRedirect();

    const itemLink = id => `/hosts/${id}`;

    const onRowClicked = (id) => {
        redirect(itemLink(id));
    };

    return <CustomTable columns={columns} rows={hosts.map(host => createRow(host))} handleRowClick={onRowClicked} itemLink={itemLink} totalCount={totalCount}
        lazyParams={lazyParams} setLazyParams={setLazyParams} columnSort={columnSort} setColumnSort={setColumnSort} rowsPerPage={rowsPerPage} loading={loading} />;
}