import React from "react";
import { formatDate } from "../../components/common/Helper";
import { mount } from "@cypress/react";
import { composeStories } from "@storybook/testing-react";
import * as stories from "./DeploymentDetailsContainer.stories";

const {Default} = composeStories(stories)

function commonTests() {
  cy.wait("@getDeploymentJob")

  // Expected in Info table:
  cy.contains("CCCE:SC-IOC-001") // ioc name
  cy.contains("ee3ae2a8") // git reference
  cy.contains("jsparger-test.cslab.esss.lu.se") // host
  cy.contains("https://gitlab.esss.lu.se/ccce/dev/iocs/ccce-demo-w38.git") // git repository
  cy.contains("https://awx-lab-01.cslab.esss.lu.se/#/jobs/playbook/3925")  // awx job link
  cy.contains(formatDate("2022-02-11T12:29:24.332+00:00")) // start time
  cy.contains(formatDate("2022-02-11T12:29:29.595+00:00")) // finish time


  // Expected alert message
  cy.get(".MuiAlert-message").contains("The deployment job failed")

  // Stepper
  cy.get(".MuiStep-completed").contains("Creating Deployment")
  cy.get(".MuiStep-completed").contains("Deployment Queued")
  cy.get(".Mui-error").contains("Running Deployment")
  cy.get(".Mui-disabled").contains("Deployment Completed")
}

describe("DeploymentDetailsContainer", () => {
  context("when not logged in", () => {
    it("displays the non-logged in view", () => {
      mount(<Default />)
      commonTests();
    })
  })

  context("when logged in", () => {
    beforeEach(() => {
      cy.login();
      mount(<Default />)
    })

    it("displays the deployment", () => {
      commonTests();
      
      // Expect AWX job log to be rendered:
      cy.wait("@getDeploymentJobLog")
      cy.contains("Gathering Facts");
    })
  })
})