import React, { useState, useEffect } from 'react';
import {
    Paper,
    Link,
    Container,
    IconButton,
    Card,
    CardContent,
    Typography,
} from '@material-ui/core';
import { makeStyles } from '@material-ui/core/styles';
import ArrowBackIcon from '@material-ui/icons/ArrowBack';
import { useHostIOCList, } from '../../api/SwaggerApi';
import { HostBadge } from '../../components/host/HostBadge';
import { SimpleAccordion } from '../../components/common/Accordion/SimpleAccordion';
import { IOCAsyncList } from "../../components/IOC/IOCAsyncList";
import { KeyValueTable } from '../../components/common/KeyValueTable/KeyValueTable';
import { LokiPanel } from '../../components/common/Loki/LokiPanel';
import { useHistory } from "react-router-dom";
import { initRequestParams } from '../../components/common/Helper';
import AccessControl from '../../components/auth/AccessControl';
import { useGlobalAppBar } from '../../components/navigation/GlobalAppBar/GlobalAppBar';
import { useHost } from "../../api/SwaggerApi";
import AlertMessages from '../../components/IOC/AlertMessages';

const useStyles = makeStyles((theme) => ({
    secondItem: {
        marginTop: theme.spacing(2),
    },
}));

export function HostDetailsView({ id }) {
    const [host] = useHost(id);
    const [iocs, getIocs, /*reset*/, loading] = useHostIOCList();
    const [deployedIocs, setDeployedIocs] = useState([]);
    const history = useHistory();
    const classes = useStyles();

    const [lazyParams, setLazyParams] = useState({
        first: 0,
        rows: 5,
        page: 0
    });

    const [columnSort, setColumnSort] = useState({
        sortField: null,
        sortOrder: null
    });

    const rowsPerPage = [5, 20];

    useEffect(() => {
        let requestParams = initRequestParams(lazyParams, null, columnSort);

        requestParams.host_csentry_id = id;

        getIocs(requestParams);
    }, [getIocs, lazyParams, columnSort, id])

    useEffect(() => {
        setDeployedIocs(iocs?.deployedList ?? []);
    }, [iocs, setDeployedIocs])


    function listToString(list) {
        if (list) {
            if (Array.isArray(list)) {
                return list.join(", ");
            }
            return list;
        }

        return "";
    }

    let renderHost = {
        "registered by": host?.csEntryHost?.user,
        "device type": host?.csEntryHost?.device_type,
        description: host?.csEntryHost?.description,
        scope: host?.csEntryHost?.scope,
        "vm owner": listToString(host?.csEntryHost?.ansible_vars?.vm_owner),
        "ansible groups": listToString(host?.csEntryHost?.ansible_groups)
    }

    const handleClick = (event) => {
        history.goBack();
    };

    const { setTitle } = useGlobalAppBar("Host Details");

    useEffect(() => {
        host && host.csEntryHost && setTitle("Host Details: " + host.csEntryHost.name);
    }, [host, setTitle]);

    function accordionHeader() {
        return (
            <>
                {host && <HostBadge host={host} />}
            </>
        )
    }

    return (
        <Paper>
            <IconButton color="inherit" onClick={handleClick}>
                <ArrowBackIcon />
            </IconButton>

            {host && <AlertMessages alerts={host.alerts} />}
            
            <SimpleAccordion defaultExpanded summary={accordionHeader()}>

                <AccessControl allowedRoles={["DeploymentToolAdmin", "DeploymentToolIntegrator"]}
                    renderNoAccess={() => <></>} >

                    {host && <KeyValueTable obj={renderHost} />}

                </AccessControl>
            </SimpleAccordion>
            <SimpleAccordion summary="Deployed IOCs" defaultExpanded>
                <IOCAsyncList iocs={deployedIocs} setIocs={setDeployedIocs} loading={loading} rowType="host"
                    totalCount={iocs.totalCount} lazyParams={lazyParams} setLazyParams={setLazyParams} columnSort={columnSort} setColumnSort={setColumnSort}
                    rowsPerPage={rowsPerPage} />
            </SimpleAccordion>
            <AccessControl allowedRoles={["DeploymentToolAdmin", "DeploymentToolIntegrator"]}
                renderNoAccess={() => <></>}>
                <SimpleAccordion summary="Syslog info" defaultExpanded>
                    {host &&
                        <Container>
                            <LokiPanel host={host} isSyslog={true} isDeployed={true} />
                        </Container>}
                </SimpleAccordion>
            </AccessControl>
            <Card variant="outlined">
                <CardContent>
                    <Container>
                        <Typography variant="h6">
                            Open in CSEntry
                        </Typography>
                        <Link href={`https://csentry.esss.lu.se/network/hosts/view/${host?.csEntryHost.name}`} target="_blank" rel="noreferrer">{`https://csentry.esss.lu.se/network/hosts/view/${host?.csEntryHost?.name}`}</Link>

                        <Typography variant="h6" className={classes.secondItem}>
                            Open in Grafana
                        </Typography>
                        <Link href={`https://grafana.tn.esss.lu.se/d/5zJT23xWz/node-exporter-full?orgId=1&var-node=${host?.csEntryHost.fqdn}`} target="_blank" rel="noreferrer">{`https://grafana.tn.esss.lu.se/d/5zJT23xWz/node-exporter-full?orgId=1&var-node=${host?.csEntryHost.fqdn}`}</Link>
                    </Container>
                </CardContent>
            </Card>
        </Paper>
    );
}